@@ -47,6 +47,8 @@
 #include "views/monthview/monthview.h"
 #include "views/todoview/kotodoview.h"
 #include "widgets/navigatorbar.h"
+#include "pimmessagebox.h"
+
 
 #include <AkonadiCore/AttributeFactory>
 #include <AkonadiCore/CollectionIdentificationAttribute>
@@ -82,14 +84,13 @@
 
 #include <KHolidays/HolidayRegion>
 
-#include <Libkdepim/PIMMessageBox>
-
 #include <PimCommonAkonadi/CollectionAclPage>
 #include <PimCommonAkonadi/ImapAclAttribute>
 
+#include <KDialogJobUiDelegate>
 #include <KMessageBox>
 #include <KNotification>
-#include <KRun>
+#include <KIO/CommandLauncherJob>
 
 #include <QApplication>
 #include <QClipboard>
@@ -131,6 +132,8 @@ CalendarView::CalendarView(QWidget *parent)
     connect(mCalendarClipboard, &Akonadi::CalendarClipboard::cutFinished, this,
             &CalendarView::onCutFinished);
 
+    mChanger->setEntityTreeModel(mCalendar->entityTreeModel());
+
     Akonadi::AttributeFactory::registerAttribute<PimCommon::ImapAclAttribute>();
     Akonadi::AttributeFactory::registerAttribute<Akonadi::CollectionIdentificationAttribute>();
 
@@ -964,8 +967,8 @@ void CalendarView::dateTimesForNewEvent(QDateTime &startDt, QDateTime &endDt, bo
             // use the next quarter hour after the current time.
             // but don't spill over into tomorrow.
             const QTime currentTime = currentDateTime.time();
-            if (!prefTime.isValid() ||
-                (currentTime > prefTime && currentTime < QTime(23, 45))) {
+            if (!prefTime.isValid()
+                || (currentTime > prefTime && currentTime < QTime(23, 45))) {
                 prefTime = nextQuarterHour(currentTime);
             }
         }
@@ -1754,7 +1757,10 @@ void CalendarView::schedule(KCalendarCore::iTIPMethod method, const Akonadi::Ite
 
 void CalendarView::openAddressbook()
 {
-    KRun::runCommand(QStringLiteral("kaddressbook"), topLevelWidget());
+    KIO::CommandLauncherJob *job = new KIO::CommandLauncherJob(QStringLiteral("kaddressbook"), {}, this);
+    job->setDesktopName(QStringLiteral("org.kde.kaddressbook"));
+    job->setUiDelegate(new KDialogJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+    job->start();
 }
 
 bool CalendarView::isReadOnly() const
@@ -1863,20 +1869,6 @@ void CalendarView::eventUpdated(const Akonadi::Item &)
 //  updateView();
 }
 
-void CalendarView::adaptNavigationUnits()
-{
-    if (mViewManager->currentView()->isEventView()) {
-        int days = mViewManager->currentView()->currentDateCount();
-        if (days == 1) {
-            Q_EMIT changeNavStringPrev(i18n("&Previous Day"));
-            Q_EMIT changeNavStringNext(i18n("&Next Day"));
-        } else {
-            Q_EMIT changeNavStringPrev(i18n("&Previous Week"));
-            Q_EMIT changeNavStringNext(i18n("&Next Week"));
-        }
-    }
-}
-
 void CalendarView::processMainViewSelection(const Akonadi::Item &item, const QDate &date)
 {
     if (CalendarSupport::hasIncidence(item)) {
@@ -2403,7 +2395,7 @@ bool CalendarView::deleteIncidence(const Akonadi::Item &item, bool force)
 
                 if (!(isFirst && isLast)) {
                     QDialogButtonBox::StandardButton returnValue
-                        = KPIM::PIMMessageBox::fourBtnMsgBox(
+                        = PIMMessageBox::fourBtnMsgBox(
                               this,
                               QMessageBox::Warning,
                               message,
