@@ -27,8 +27,6 @@
 
 #include <KHolidays/HolidayRegion>
 
-#include <KIconLoader>
-
 #include <QApplication>
 
 class KOGlobalsSingletonPrivate
@@ -58,11 +56,6 @@ bool KOGlobals::reverseLayout()
     return QApplication::isRightToLeft();
 }
 
-QPixmap KOGlobals::smallIcon(const QString &name) const
-{
-    return SmallIcon(name);
-}
-
 QMap<QDate, QStringList> KOGlobals::holiday(const QDate &start, const QDate &end) const
 {
     QMap<QDate, QStringList> holidaysByDate;
