@@ -37,12 +37,18 @@ static void korganizer_options(QCommandLineParser *parser)
     parser->addOption(QCommandLineOption(
                           QStringList() << QStringLiteral("m") << QStringLiteral("merge"),
                               i18n("Merge the specified files into an existing calendar")));
+    parser->addOption(QCommandLineOption(
+                          {QStringLiteral("view")},
+                              i18n("Display the specified incidence (by URL)"), QStringLiteral("url")));
 
     parser->addPositionalArgument(
         QStringLiteral("calendars"),
         i18n("Calendar files or urls. Unless -i or -m is explicitly specified, "
              "the user will be asked whether to import or merge"),
         QStringLiteral("[calendar...]"));
+#ifdef WITH_KUSERFEEDBACK
+    parser->addOption(QCommandLineOption(QStringLiteral("feedback"), i18n("Lists the available options for user feedback")));
+#endif
 }
 
 #endif
